use anyhow::{
    Context,
};
use flake_tracker::{
    storage::{
        Storage,
    },
    web::{
        make_router,
    },
};


#[tokio::main]
async fn main() -> anyhow::Result<()> {
    let storage = Storage::connect("sqlite://flake-tracker.db")
        .await
        .context("Failed to connect to database")?;


    let app  = make_router(storage)?;

    let listener = tokio::net::TcpListener::bind("[::]:3000")
        .await
        .context("Failed to bind to port")?;

    axum::serve(listener, app)
        .await
        .context("Failed to start web server")?;

    Ok(())
}
